-------------------------------------------------------------------------------
-- system.vhd
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity system is
  port (
    RS232_RX_DATA_P : in std_logic;
    RS232_TX_DATA_P : out std_logic;
    USER_INPUT0_P : inout std_logic_vector(0 to 0);
    USER_LED0_N : inout std_logic_vector(0 to 0);
    MASTER_CLOCK_P : in std_logic;
    EXTEND_DCM_RESET_P : in std_logic;
    USER_INPUT1_P : in std_logic;
    USER_LED1_N : out std_logic
  );
end system;

architecture STRUCTURE of system is

  attribute box_type : string;

  component mblaze_wrapper is
    port (
      CLK : in std_logic;
      RESET : in std_logic;
      INTERRUPT : in std_logic;
      DEBUG_RST : in std_logic;
      EXT_BRK : in std_logic;
      EXT_NM_BRK : in std_logic;
      DBG_STOP : in std_logic;
      INSTR : in std_logic_vector(0 to 31);
      IREADY : in std_logic;
      INSTR_ADDR : out std_logic_vector(0 to 31);
      IFETCH : out std_logic;
      I_AS : out std_logic;
      DATA_READ : in std_logic_vector(0 to 31);
      DREADY : in std_logic;
      DATA_WRITE : out std_logic_vector(0 to 31);
      DATA_ADDR : out std_logic_vector(0 to 31);
      D_AS : out std_logic;
      READ_STROBE : out std_logic;
      WRITE_STROBE : out std_logic;
      BYTE_ENABLE : out std_logic_vector(0 to 3);
      DM_ABUS : out std_logic_vector(0 to 31);
      DM_BE : out std_logic_vector(0 to 3);
      DM_BUSLOCK : out std_logic;
      DM_DBUS : out std_logic_vector(0 to 31);
      DM_REQUEST : out std_logic;
      DM_RNW : out std_logic;
      DM_SELECT : out std_logic;
      DM_SEQADDR : out std_logic;
      DOPB_DBUS : in std_logic_vector(0 to 31);
      DOPB_ERRACK : in std_logic;
      DOPB_MGRANT : in std_logic;
      DOPB_RETRY : in std_logic;
      DOPB_TIMEOUT : in std_logic;
      DOPB_XFERACK : in std_logic;
      IM_ABUS : out std_logic_vector(0 to 31);
      IM_BE : out std_logic_vector(0 to 3);
      IM_BUSLOCK : out std_logic;
      IM_DBUS : out std_logic_vector(0 to 31);
      IM_REQUEST : out std_logic;
      IM_RNW : out std_logic;
      IM_SELECT : out std_logic;
      IM_SEQADDR : out std_logic;
      IOPB_DBUS : in std_logic_vector(0 to 31);
      IOPB_ERRACK : in std_logic;
      IOPB_MGRANT : in std_logic;
      IOPB_RETRY : in std_logic;
      IOPB_TIMEOUT : in std_logic;
      IOPB_XFERACK : in std_logic;
      DBG_CLK : in std_logic;
      DBG_TDI : in std_logic;
      DBG_TDO : out std_logic;
      DBG_REG_EN : in std_logic_vector(0 to 4);
      DBG_CAPTURE : in std_logic;
      DBG_UPDATE : in std_logic;
      VALID_INSTR : out std_logic;
      PC_EX : out std_logic_vector(0 to 31);
      REG_WRITE : out std_logic;
      REG_ADDR : out std_logic_vector(0 to 4);
      MSR_REG : out std_logic_vector(0 to 7);
      NEW_REG_VALUE : out std_logic_vector(0 to 31);
      PIPE_RUNNING : out std_logic;
      INTERRUPT_TAKEN : out std_logic;
      JUMP_TAKEN : out std_logic;
      PREFETCH_ADDR : out std_logic_vector(0 to 3);
      MB_Halted : out std_logic;
      FSL0_S_CLK : out std_logic;
      FSL0_S_READ : out std_logic;
      FSL0_S_DATA : in std_logic_vector(0 to 31);
      FSL0_S_CONTROL : in std_logic;
      FSL0_S_EXISTS : in std_logic;
      FSL0_M_CLK : out std_logic;
      FSL0_M_WRITE : out std_logic;
      FSL0_M_DATA : out std_logic_vector(0 to 31);
      FSL0_M_CONTROL : out std_logic;
      FSL0_M_FULL : in std_logic;
      FSL1_S_CLK : out std_logic;
      FSL1_S_READ : out std_logic;
      FSL1_S_DATA : in std_logic_vector(0 to 31);
      FSL1_S_CONTROL : in std_logic;
      FSL1_S_EXISTS : in std_logic;
      FSL1_M_CLK : out std_logic;
      FSL1_M_WRITE : out std_logic;
      FSL1_M_DATA : out std_logic_vector(0 to 31);
      FSL1_M_CONTROL : out std_logic;
      FSL1_M_FULL : in std_logic;
      FSL2_S_CLK : out std_logic;
      FSL2_S_READ : out std_logic;
      FSL2_S_DATA : in std_logic_vector(0 to 31);
      FSL2_S_CONTROL : in std_logic;
      FSL2_S_EXISTS : in std_logic;
      FSL2_M_CLK : out std_logic;
      FSL2_M_WRITE : out std_logic;
      FSL2_M_DATA : out std_logic_vector(0 to 31);
      FSL2_M_CONTROL : out std_logic;
      FSL2_M_FULL : in std_logic;
      FSL3_S_CLK : out std_logic;
      FSL3_S_READ : out std_logic;
      FSL3_S_DATA : in std_logic_vector(0 to 31);
      FSL3_S_CONTROL : in std_logic;
      FSL3_S_EXISTS : in std_logic;
      FSL3_M_CLK : out std_logic;
      FSL3_M_WRITE : out std_logic;
      FSL3_M_DATA : out std_logic_vector(0 to 31);
      FSL3_M_CONTROL : out std_logic;
      FSL3_M_FULL : in std_logic;
      FSL4_S_CLK : out std_logic;
      FSL4_S_READ : out std_logic;
      FSL4_S_DATA : in std_logic_vector(0 to 31);
      FSL4_S_CONTROL : in std_logic;
      FSL4_S_EXISTS : in std_logic;
      FSL4_M_CLK : out std_logic;
      FSL4_M_WRITE : out std_logic;
      FSL4_M_DATA : out std_logic_vector(0 to 31);
      FSL4_M_CONTROL : out std_logic;
      FSL4_M_FULL : in std_logic;
      FSL5_S_CLK : out std_logic;
      FSL5_S_READ : out std_logic;
      FSL5_S_DATA : in std_logic_vector(0 to 31);
      FSL5_S_CONTROL : in std_logic;
      FSL5_S_EXISTS : in std_logic;
      FSL5_M_CLK : out std_logic;
      FSL5_M_WRITE : out std_logic;
      FSL5_M_DATA : out std_logic_vector(0 to 31);
      FSL5_M_CONTROL : out std_logic;
      FSL5_M_FULL : in std_logic;
      FSL6_S_CLK : out std_logic;
      FSL6_S_READ : out std_logic;
      FSL6_S_DATA : in std_logic_vector(0 to 31);
      FSL6_S_CONTROL : in std_logic;
      FSL6_S_EXISTS : in std_logic;
      FSL6_M_CLK : out std_logic;
      FSL6_M_WRITE : out std_logic;
      FSL6_M_DATA : out std_logic_vector(0 to 31);
      FSL6_M_CONTROL : out std_logic;
      FSL6_M_FULL : in std_logic;
      FSL7_S_CLK : out std_logic;
      FSL7_S_READ : out std_logic;
      FSL7_S_DATA : in std_logic_vector(0 to 31);
      FSL7_S_CONTROL : in std_logic;
      FSL7_S_EXISTS : in std_logic;
      FSL7_M_CLK : out std_logic;
      FSL7_M_WRITE : out std_logic;
      FSL7_M_DATA : out std_logic_vector(0 to 31);
      FSL7_M_CONTROL : out std_logic;
      FSL7_M_FULL : in std_logic
    );
  end component;

  attribute box_type of mblaze_wrapper: component is "black_box";

  component bram_wrapper is
    port (
      BRAM_Rst_A : in std_logic;
      BRAM_Clk_A : in std_logic;
      BRAM_EN_A : in std_logic;
      BRAM_WEN_A : in std_logic_vector(0 to 3);
      BRAM_Addr_A : in std_logic_vector(0 to 31);
      BRAM_Din_A : out std_logic_vector(0 to 31);
      BRAM_Dout_A : in std_logic_vector(0 to 31);
      BRAM_Rst_B : in std_logic;
      BRAM_Clk_B : in std_logic;
      BRAM_EN_B : in std_logic;
      BRAM_WEN_B : in std_logic_vector(0 to 3);
      BRAM_Addr_B : in std_logic_vector(0 to 31);
      BRAM_Din_B : out std_logic_vector(0 to 31);
      BRAM_Dout_B : in std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of bram_wrapper: component is "black_box";

  component bram_data_ctrl_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of bram_data_ctrl_wrapper: component is "black_box";

  component bram_inst_ctrl_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of bram_inst_ctrl_wrapper: component is "black_box";

  component jtag_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Interrupt : out std_logic;
      Debug_SYS_Rst : out std_logic;
      Debug_Rst : out std_logic;
      Ext_BRK : out std_logic;
      Ext_NM_BRK : out std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      JTAG_UART_DBus : out std_logic_vector(0 to 31);
      JTAG_UART_errAck : out std_logic;
      JTAG_UART_retry : out std_logic;
      JTAG_UART_toutSup : out std_logic;
      JTAG_UART_xferAck : out std_logic
    );
  end component;

  attribute box_type of jtag_wrapper: component is "black_box";

  component uart_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Interrupt : out std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      UART_DBus : out std_logic_vector(0 to 31);
      UART_errAck : out std_logic;
      UART_retry : out std_logic;
      UART_toutSup : out std_logic;
      UART_xferAck : out std_logic;
      RX : in std_logic;
      TX : out std_logic
    );
  end component;

  attribute box_type of uart_wrapper: component is "black_box";

  component data_lmb_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of data_lmb_wrapper: component is "black_box";

  component inst_lmb_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of inst_lmb_wrapper: component is "black_box";

  component opb_bus_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : out std_logic;
      SYS_Rst : in std_logic;
      Debug_SYS_Rst : in std_logic;
      WDT_Rst : in std_logic;
      M_ABus : in std_logic_vector(0 to 63);
      M_BE : in std_logic_vector(0 to 7);
      M_beXfer : in std_logic_vector(0 to 1);
      M_busLock : in std_logic_vector(0 to 1);
      M_DBus : in std_logic_vector(0 to 63);
      M_DBusEn : in std_logic_vector(0 to 1);
      M_DBusEn32_63 : in std_logic_vector(0 to 1);
      M_dwXfer : in std_logic_vector(0 to 1);
      M_fwXfer : in std_logic_vector(0 to 1);
      M_hwXfer : in std_logic_vector(0 to 1);
      M_request : in std_logic_vector(0 to 1);
      M_RNW : in std_logic_vector(0 to 1);
      M_select : in std_logic_vector(0 to 1);
      M_seqAddr : in std_logic_vector(0 to 1);
      Sl_beAck : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 127);
      Sl_DBusEn : in std_logic_vector(0 to 3);
      Sl_DBusEn32_63 : in std_logic_vector(0 to 3);
      Sl_errAck : in std_logic_vector(0 to 3);
      Sl_dwAck : in std_logic_vector(0 to 3);
      Sl_fwAck : in std_logic_vector(0 to 3);
      Sl_hwAck : in std_logic_vector(0 to 3);
      Sl_retry : in std_logic_vector(0 to 3);
      Sl_toutSup : in std_logic_vector(0 to 3);
      Sl_xferAck : in std_logic_vector(0 to 3);
      OPB_MRequest : out std_logic_vector(0 to 1);
      OPB_ABus : out std_logic_vector(0 to 31);
      OPB_BE : out std_logic_vector(0 to 3);
      OPB_beXfer : out std_logic;
      OPB_beAck : out std_logic;
      OPB_busLock : out std_logic;
      OPB_rdDBus : out std_logic_vector(0 to 31);
      OPB_wrDBus : out std_logic_vector(0 to 31);
      OPB_DBus : out std_logic_vector(0 to 31);
      OPB_errAck : out std_logic;
      OPB_dwAck : out std_logic;
      OPB_dwXfer : out std_logic;
      OPB_fwAck : out std_logic;
      OPB_fwXfer : out std_logic;
      OPB_hwAck : out std_logic;
      OPB_hwXfer : out std_logic;
      OPB_MGrant : out std_logic_vector(0 to 1);
      OPB_pendReq : out std_logic_vector(0 to 1);
      OPB_retry : out std_logic;
      OPB_RNW : out std_logic;
      OPB_select : out std_logic;
      OPB_seqAddr : out std_logic;
      OPB_timeout : out std_logic;
      OPB_toutSup : out std_logic;
      OPB_xferAck : out std_logic
    );
  end component;

  attribute box_type of opb_bus_wrapper: component is "black_box";

  component gpio_switch0_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      GPIO_DBus : out std_logic_vector(0 to 31);
      GPIO_errAck : out std_logic;
      GPIO_retry : out std_logic;
      GPIO_toutSup : out std_logic;
      GPIO_xferAck : out std_logic;
      GPIO_IO_I : in std_logic_vector(0 to 0);
      GPIO_IO_O : out std_logic_vector(0 to 0);
      GPIO_IO_T : out std_logic_vector(0 to 0)
    );
  end component;

  attribute box_type of gpio_switch0_wrapper: component is "black_box";

  component gpio_led0_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      GPIO_DBus : out std_logic_vector(0 to 31);
      GPIO_errAck : out std_logic;
      GPIO_retry : out std_logic;
      GPIO_toutSup : out std_logic;
      GPIO_xferAck : out std_logic;
      GPIO_IO_I : in std_logic_vector(0 to 0);
      GPIO_IO_O : out std_logic_vector(0 to 0);
      GPIO_IO_T : out std_logic_vector(0 to 0)
    );
  end component;

  attribute box_type of gpio_led0_wrapper: component is "black_box";

  component IBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  component OBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  component IOBUF is
    port (
      I : in std_logic;
      IO : inout std_logic;
      O : out std_logic;
      T : in std_logic
    );
  end component;

  component BUFGP is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  -- Internal signals

  signal Debug_Rst : std_logic;
  signal Ext_BRK : std_logic;
  signal Ext_NM_BRK : std_logic;
  signal RS232_RX_DATA_P_IBUF : std_logic;
  signal RS232_TX_DATA_P_OBUF : std_logic;
  signal USER_INPUT0_P_I : std_logic_vector(0 to 0);
  signal USER_INPUT0_P_O : std_logic_vector(0 to 0);
  signal USER_INPUT0_P_T : std_logic_vector(0 to 0);
  signal USER_LED0_N_I : std_logic_vector(0 to 0);
  signal USER_LED0_N_O : std_logic_vector(0 to 0);
  signal USER_LED0_N_T : std_logic_vector(0 to 0);
  signal clk_27mhz : std_logic;
  signal data_lmb_LMB_ABus : std_logic_vector(0 to 31);
  signal data_lmb_LMB_AddrStrobe : std_logic;
  signal data_lmb_LMB_BE : std_logic_vector(0 to 3);
  signal data_lmb_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal data_lmb_LMB_ReadStrobe : std_logic;
  signal data_lmb_LMB_Ready : std_logic;
  signal data_lmb_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal data_lmb_LMB_WriteStrobe : std_logic;
  signal data_lmb_M_ABus : std_logic_vector(0 to 31);
  signal data_lmb_M_AddrStrobe : std_logic;
  signal data_lmb_M_BE : std_logic_vector(0 to 3);
  signal data_lmb_M_DBus : std_logic_vector(0 to 31);
  signal data_lmb_M_ReadStrobe : std_logic;
  signal data_lmb_M_WriteStrobe : std_logic;
  signal data_lmb_OPB_Rst : std_logic;
  signal data_lmb_Sl_DBus : std_logic_vector(0 to 31);
  signal data_lmb_Sl_Ready : std_logic_vector(0 to 0);
  signal fpga_reset : std_logic;
  signal inst_lmb_LMB_ABus : std_logic_vector(0 to 31);
  signal inst_lmb_LMB_AddrStrobe : std_logic;
  signal inst_lmb_LMB_BE : std_logic_vector(0 to 3);
  signal inst_lmb_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal inst_lmb_LMB_ReadStrobe : std_logic;
  signal inst_lmb_LMB_Ready : std_logic;
  signal inst_lmb_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal inst_lmb_LMB_WriteStrobe : std_logic;
  signal inst_lmb_M_ABus : std_logic_vector(0 to 31);
  signal inst_lmb_M_AddrStrobe : std_logic;
  signal inst_lmb_M_ReadStrobe : std_logic;
  signal inst_lmb_OPB_Rst : std_logic;
  signal inst_lmb_Sl_DBus : std_logic_vector(0 to 31);
  signal inst_lmb_Sl_Ready : std_logic_vector(0 to 0);
  signal net_gnd0 : std_logic;
  signal net_gnd2 : std_logic_vector(0 to 1);
  signal net_gnd32 : std_logic_vector(0 to 31);
  signal net_gnd4 : std_logic_vector(0 to 3);
  signal net_gnd5 : std_logic_vector(0 to 4);
  signal net_vcc2 : std_logic_vector(0 to 1);
  signal net_vcc4 : std_logic_vector(0 to 3);
  signal opb_bus_Debug_SYS_Rst : std_logic;
  signal opb_bus_M_ABus : std_logic_vector(0 to 63);
  signal opb_bus_M_BE : std_logic_vector(0 to 7);
  signal opb_bus_M_DBus : std_logic_vector(0 to 63);
  signal opb_bus_M_RNW : std_logic_vector(0 to 1);
  signal opb_bus_M_busLock : std_logic_vector(0 to 1);
  signal opb_bus_M_request : std_logic_vector(0 to 1);
  signal opb_bus_M_select : std_logic_vector(0 to 1);
  signal opb_bus_M_seqAddr : std_logic_vector(0 to 1);
  signal opb_bus_OPB_ABus : std_logic_vector(0 to 31);
  signal opb_bus_OPB_BE : std_logic_vector(0 to 3);
  signal opb_bus_OPB_DBus : std_logic_vector(0 to 31);
  signal opb_bus_OPB_MGrant : std_logic_vector(0 to 1);
  signal opb_bus_OPB_RNW : std_logic;
  signal opb_bus_OPB_Rst : std_logic;
  signal opb_bus_OPB_errAck : std_logic;
  signal opb_bus_OPB_retry : std_logic;
  signal opb_bus_OPB_select : std_logic;
  signal opb_bus_OPB_seqAddr : std_logic;
  signal opb_bus_OPB_timeout : std_logic;
  signal opb_bus_OPB_xferAck : std_logic;
  signal opb_bus_Sl_DBus : std_logic_vector(0 to 127);
  signal opb_bus_Sl_errAck : std_logic_vector(0 to 3);
  signal opb_bus_Sl_retry : std_logic_vector(0 to 3);
  signal opb_bus_Sl_toutSup : std_logic_vector(0 to 3);
  signal opb_bus_Sl_xferAck : std_logic_vector(0 to 3);
  signal porta_BRAM_Addr : std_logic_vector(0 to 31);
  signal porta_BRAM_Clk : std_logic;
  signal porta_BRAM_Din : std_logic_vector(0 to 31);
  signal porta_BRAM_Dout : std_logic_vector(0 to 31);
  signal porta_BRAM_EN : std_logic;
  signal porta_BRAM_Rst : std_logic;
  signal porta_BRAM_WEN : std_logic_vector(0 to 3);
  signal portb_BRAM_Addr : std_logic_vector(0 to 31);
  signal portb_BRAM_Clk : std_logic;
  signal portb_BRAM_Din : std_logic_vector(0 to 31);
  signal portb_BRAM_Dout : std_logic_vector(0 to 31);
  signal portb_BRAM_EN : std_logic;
  signal portb_BRAM_Rst : std_logic;
  signal portb_BRAM_WEN : std_logic_vector(0 to 3);
  signal switch1_led1 : std_logic;

begin

  -- Internal assignments

  net_gnd0 <= '0';
  net_gnd2(0 to 1) <= B"00";
  net_gnd32(0 to 31) <= B"00000000000000000000000000000000";
  net_gnd4(0 to 3) <= B"0000";
  net_gnd5(0 to 4) <= B"00000";
  net_vcc2(0 to 1) <= B"11";
  net_vcc4(0 to 3) <= B"1111";

  mblaze : mblaze_wrapper
    port map (
      CLK => clk_27mhz,
      RESET => opb_bus_OPB_Rst,
      INTERRUPT => net_gnd0,
      DEBUG_RST => Debug_Rst,
      EXT_BRK => Ext_BRK,
      EXT_NM_BRK => Ext_NM_BRK,
      DBG_STOP => net_gnd0,
      INSTR => inst_lmb_LMB_ReadDBus,
      IREADY => inst_lmb_LMB_Ready,
      INSTR_ADDR => inst_lmb_M_ABus,
      IFETCH => inst_lmb_M_ReadStrobe,
      I_AS => inst_lmb_M_AddrStrobe,
      DATA_READ => data_lmb_LMB_ReadDBus,
      DREADY => data_lmb_LMB_Ready,
      DATA_WRITE => data_lmb_M_DBus,
      DATA_ADDR => data_lmb_M_ABus,
      D_AS => data_lmb_M_AddrStrobe,
      READ_STROBE => data_lmb_M_ReadStrobe,
      WRITE_STROBE => data_lmb_M_WriteStrobe,
      BYTE_ENABLE => data_lmb_M_BE,
      DM_ABUS => opb_bus_M_ABus(0 to 31),
      DM_BE => opb_bus_M_BE(0 to 3),
      DM_BUSLOCK => opb_bus_M_busLock(0),
      DM_DBUS => opb_bus_M_DBus(0 to 31),
      DM_REQUEST => opb_bus_M_request(0),
      DM_RNW => opb_bus_M_RNW(0),
      DM_SELECT => opb_bus_M_select(0),
      DM_SEQADDR => opb_bus_M_seqAddr(0),
      DOPB_DBUS => opb_bus_OPB_DBus,
      DOPB_ERRACK => opb_bus_OPB_errAck,
      DOPB_MGRANT => opb_bus_OPB_MGrant(0),
      DOPB_RETRY => opb_bus_OPB_retry,
      DOPB_TIMEOUT => opb_bus_OPB_timeout,
      DOPB_XFERACK => opb_bus_OPB_xferAck,
      IM_ABUS => opb_bus_M_ABus(32 to 63),
      IM_BE => opb_bus_M_BE(4 to 7),
      IM_BUSLOCK => opb_bus_M_busLock(1),
      IM_DBUS => opb_bus_M_DBus(32 to 63),
      IM_REQUEST => opb_bus_M_request(1),
      IM_RNW => opb_bus_M_RNW(1),
      IM_SELECT => opb_bus_M_select(1),
      IM_SEQADDR => opb_bus_M_seqAddr(1),
      IOPB_DBUS => opb_bus_OPB_DBus,
      IOPB_ERRACK => opb_bus_OPB_errAck,
      IOPB_MGRANT => opb_bus_OPB_MGrant(1),
      IOPB_RETRY => opb_bus_OPB_retry,
      IOPB_TIMEOUT => opb_bus_OPB_timeout,
      IOPB_XFERACK => opb_bus_OPB_xferAck,
      DBG_CLK => net_gnd0,
      DBG_TDI => net_gnd0,
      DBG_TDO => open,
      DBG_REG_EN => net_gnd5,
      DBG_CAPTURE => net_gnd0,
      DBG_UPDATE => net_gnd0,
      VALID_INSTR => open,
      PC_EX => open,
      REG_WRITE => open,
      REG_ADDR => open,
      MSR_REG => open,
      NEW_REG_VALUE => open,
      PIPE_RUNNING => open,
      INTERRUPT_TAKEN => open,
      JUMP_TAKEN => open,
      PREFETCH_ADDR => open,
      MB_Halted => open,
      FSL0_S_CLK => open,
      FSL0_S_READ => open,
      FSL0_S_DATA => net_gnd32,
      FSL0_S_CONTROL => net_gnd0,
      FSL0_S_EXISTS => net_gnd0,
      FSL0_M_CLK => open,
      FSL0_M_WRITE => open,
      FSL0_M_DATA => open,
      FSL0_M_CONTROL => open,
      FSL0_M_FULL => net_gnd0,
      FSL1_S_CLK => open,
      FSL1_S_READ => open,
      FSL1_S_DATA => net_gnd32,
      FSL1_S_CONTROL => net_gnd0,
      FSL1_S_EXISTS => net_gnd0,
      FSL1_M_CLK => open,
      FSL1_M_WRITE => open,
      FSL1_M_DATA => open,
      FSL1_M_CONTROL => open,
      FSL1_M_FULL => net_gnd0,
      FSL2_S_CLK => open,
      FSL2_S_READ => open,
      FSL2_S_DATA => net_gnd32,
      FSL2_S_CONTROL => net_gnd0,
      FSL2_S_EXISTS => net_gnd0,
      FSL2_M_CLK => open,
      FSL2_M_WRITE => open,
      FSL2_M_DATA => open,
      FSL2_M_CONTROL => open,
      FSL2_M_FULL => net_gnd0,
      FSL3_S_CLK => open,
      FSL3_S_READ => open,
      FSL3_S_DATA => net_gnd32,
      FSL3_S_CONTROL => net_gnd0,
      FSL3_S_EXISTS => net_gnd0,
      FSL3_M_CLK => open,
      FSL3_M_WRITE => open,
      FSL3_M_DATA => open,
      FSL3_M_CONTROL => open,
      FSL3_M_FULL => net_gnd0,
      FSL4_S_CLK => open,
      FSL4_S_READ => open,
      FSL4_S_DATA => net_gnd32,
      FSL4_S_CONTROL => net_gnd0,
      FSL4_S_EXISTS => net_gnd0,
      FSL4_M_CLK => open,
      FSL4_M_WRITE => open,
      FSL4_M_DATA => open,
      FSL4_M_CONTROL => open,
      FSL4_M_FULL => net_gnd0,
      FSL5_S_CLK => open,
      FSL5_S_READ => open,
      FSL5_S_DATA => net_gnd32,
      FSL5_S_CONTROL => net_gnd0,
      FSL5_S_EXISTS => net_gnd0,
      FSL5_M_CLK => open,
      FSL5_M_WRITE => open,
      FSL5_M_DATA => open,
      FSL5_M_CONTROL => open,
      FSL5_M_FULL => net_gnd0,
      FSL6_S_CLK => open,
      FSL6_S_READ => open,
      FSL6_S_DATA => net_gnd32,
      FSL6_S_CONTROL => net_gnd0,
      FSL6_S_EXISTS => net_gnd0,
      FSL6_M_CLK => open,
      FSL6_M_WRITE => open,
      FSL6_M_DATA => open,
      FSL6_M_CONTROL => open,
      FSL6_M_FULL => net_gnd0,
      FSL7_S_CLK => open,
      FSL7_S_READ => open,
      FSL7_S_DATA => net_gnd32,
      FSL7_S_CONTROL => net_gnd0,
      FSL7_S_EXISTS => net_gnd0,
      FSL7_M_CLK => open,
      FSL7_M_WRITE => open,
      FSL7_M_DATA => open,
      FSL7_M_CONTROL => open,
      FSL7_M_FULL => net_gnd0
    );

  bram : bram_wrapper
    port map (
      BRAM_Rst_A => porta_BRAM_Rst,
      BRAM_Clk_A => porta_BRAM_Clk,
      BRAM_EN_A => porta_BRAM_EN,
      BRAM_WEN_A => porta_BRAM_WEN,
      BRAM_Addr_A => porta_BRAM_Addr,
      BRAM_Din_A => porta_BRAM_Din,
      BRAM_Dout_A => porta_BRAM_Dout,
      BRAM_Rst_B => portb_BRAM_Rst,
      BRAM_Clk_B => portb_BRAM_Clk,
      BRAM_EN_B => portb_BRAM_EN,
      BRAM_WEN_B => portb_BRAM_WEN,
      BRAM_Addr_B => portb_BRAM_Addr,
      BRAM_Din_B => portb_BRAM_Din,
      BRAM_Dout_B => portb_BRAM_Dout
    );

  bram_data_ctrl : bram_data_ctrl_wrapper
    port map (
      LMB_Clk => clk_27mhz,
      LMB_Rst => inst_lmb_OPB_Rst,
      LMB_ABus => inst_lmb_LMB_ABus,
      LMB_WriteDBus => inst_lmb_LMB_WriteDBus,
      LMB_AddrStrobe => inst_lmb_LMB_AddrStrobe,
      LMB_ReadStrobe => inst_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => inst_lmb_LMB_WriteStrobe,
      LMB_BE => inst_lmb_LMB_BE,
      Sl_DBus => inst_lmb_Sl_DBus,
      Sl_Ready => inst_lmb_Sl_Ready(0),
      BRAM_Rst_A => porta_BRAM_Rst,
      BRAM_Clk_A => porta_BRAM_Clk,
      BRAM_EN_A => porta_BRAM_EN,
      BRAM_WEN_A => porta_BRAM_WEN,
      BRAM_Addr_A => porta_BRAM_Addr,
      BRAM_Din_A => porta_BRAM_Din,
      BRAM_Dout_A => porta_BRAM_Dout
    );

  bram_inst_ctrl : bram_inst_ctrl_wrapper
    port map (
      LMB_Clk => clk_27mhz,
      LMB_Rst => data_lmb_OPB_Rst,
      LMB_ABus => data_lmb_LMB_ABus,
      LMB_WriteDBus => data_lmb_LMB_WriteDBus,
      LMB_AddrStrobe => data_lmb_LMB_AddrStrobe,
      LMB_ReadStrobe => data_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => data_lmb_LMB_WriteStrobe,
      LMB_BE => data_lmb_LMB_BE,
      Sl_DBus => data_lmb_Sl_DBus,
      Sl_Ready => data_lmb_Sl_Ready(0),
      BRAM_Rst_A => portb_BRAM_Rst,
      BRAM_Clk_A => portb_BRAM_Clk,
      BRAM_EN_A => portb_BRAM_EN,
      BRAM_WEN_A => portb_BRAM_WEN,
      BRAM_Addr_A => portb_BRAM_Addr,
      BRAM_Din_A => portb_BRAM_Din,
      BRAM_Dout_A => portb_BRAM_Dout
    );

  jtag : jtag_wrapper
    port map (
      OPB_Clk => clk_27mhz,
      OPB_Rst => opb_bus_OPB_Rst,
      Interrupt => open,
      Debug_SYS_Rst => opb_bus_Debug_SYS_Rst,
      Debug_Rst => Debug_Rst,
      Ext_BRK => Ext_BRK,
      Ext_NM_BRK => Ext_NM_BRK,
      OPB_ABus => opb_bus_OPB_ABus,
      OPB_BE => opb_bus_OPB_BE,
      OPB_RNW => opb_bus_OPB_RNW,
      OPB_select => opb_bus_OPB_select,
      OPB_seqAddr => opb_bus_OPB_seqAddr,
      OPB_DBus => opb_bus_OPB_DBus,
      JTAG_UART_DBus => opb_bus_Sl_DBus(0 to 31),
      JTAG_UART_errAck => opb_bus_Sl_errAck(0),
      JTAG_UART_retry => opb_bus_Sl_retry(0),
      JTAG_UART_toutSup => opb_bus_Sl_toutSup(0),
      JTAG_UART_xferAck => opb_bus_Sl_xferAck(0)
    );

  uart : uart_wrapper
    port map (
      OPB_Clk => clk_27mhz,
      OPB_Rst => opb_bus_OPB_Rst,
      Interrupt => open,
      OPB_ABus => opb_bus_OPB_ABus,
      OPB_BE => opb_bus_OPB_BE,
      OPB_RNW => opb_bus_OPB_RNW,
      OPB_select => opb_bus_OPB_select,
      OPB_seqAddr => opb_bus_OPB_seqAddr,
      OPB_DBus => opb_bus_OPB_DBus,
      UART_DBus => opb_bus_Sl_DBus(32 to 63),
      UART_errAck => opb_bus_Sl_errAck(1),
      UART_retry => opb_bus_Sl_retry(1),
      UART_toutSup => opb_bus_Sl_toutSup(1),
      UART_xferAck => opb_bus_Sl_xferAck(1),
      RX => RS232_RX_DATA_P_IBUF,
      TX => RS232_TX_DATA_P_OBUF
    );

  data_lmb : data_lmb_wrapper
    port map (
      LMB_Clk => clk_27mhz,
      SYS_Rst => fpga_reset,
      LMB_Rst => data_lmb_OPB_Rst,
      M_ABus => data_lmb_M_ABus,
      M_ReadStrobe => data_lmb_M_ReadStrobe,
      M_WriteStrobe => data_lmb_M_WriteStrobe,
      M_AddrStrobe => data_lmb_M_AddrStrobe,
      M_DBus => data_lmb_M_DBus,
      M_BE => data_lmb_M_BE,
      Sl_DBus => data_lmb_Sl_DBus,
      Sl_Ready => data_lmb_Sl_Ready(0 to 0),
      LMB_ABus => data_lmb_LMB_ABus,
      LMB_ReadStrobe => data_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => data_lmb_LMB_WriteStrobe,
      LMB_AddrStrobe => data_lmb_LMB_AddrStrobe,
      LMB_ReadDBus => data_lmb_LMB_ReadDBus,
      LMB_WriteDBus => data_lmb_LMB_WriteDBus,
      LMB_Ready => data_lmb_LMB_Ready,
      LMB_BE => data_lmb_LMB_BE
    );

  inst_lmb : inst_lmb_wrapper
    port map (
      LMB_Clk => clk_27mhz,
      SYS_Rst => fpga_reset,
      LMB_Rst => inst_lmb_OPB_Rst,
      M_ABus => inst_lmb_M_ABus,
      M_ReadStrobe => inst_lmb_M_ReadStrobe,
      M_WriteStrobe => net_gnd0,
      M_AddrStrobe => inst_lmb_M_AddrStrobe,
      M_DBus => net_gnd32,
      M_BE => net_gnd4,
      Sl_DBus => inst_lmb_Sl_DBus,
      Sl_Ready => inst_lmb_Sl_Ready(0 to 0),
      LMB_ABus => inst_lmb_LMB_ABus,
      LMB_ReadStrobe => inst_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => inst_lmb_LMB_WriteStrobe,
      LMB_AddrStrobe => inst_lmb_LMB_AddrStrobe,
      LMB_ReadDBus => inst_lmb_LMB_ReadDBus,
      LMB_WriteDBus => inst_lmb_LMB_WriteDBus,
      LMB_Ready => inst_lmb_LMB_Ready,
      LMB_BE => inst_lmb_LMB_BE
    );

  opb_bus : opb_bus_wrapper
    port map (
      OPB_Clk => clk_27mhz,
      OPB_Rst => opb_bus_OPB_Rst,
      SYS_Rst => fpga_reset,
      Debug_SYS_Rst => opb_bus_Debug_SYS_Rst,
      WDT_Rst => net_gnd0,
      M_ABus => opb_bus_M_ABus,
      M_BE => opb_bus_M_BE,
      M_beXfer => net_gnd2,
      M_busLock => opb_bus_M_busLock,
      M_DBus => opb_bus_M_DBus,
      M_DBusEn => net_gnd2,
      M_DBusEn32_63 => net_vcc2,
      M_dwXfer => net_gnd2,
      M_fwXfer => net_gnd2,
      M_hwXfer => net_gnd2,
      M_request => opb_bus_M_request,
      M_RNW => opb_bus_M_RNW,
      M_select => opb_bus_M_select,
      M_seqAddr => opb_bus_M_seqAddr,
      Sl_beAck => net_gnd4,
      Sl_DBus => opb_bus_Sl_DBus,
      Sl_DBusEn => net_vcc4,
      Sl_DBusEn32_63 => net_vcc4,
      Sl_errAck => opb_bus_Sl_errAck,
      Sl_dwAck => net_gnd4,
      Sl_fwAck => net_gnd4,
      Sl_hwAck => net_gnd4,
      Sl_retry => opb_bus_Sl_retry,
      Sl_toutSup => opb_bus_Sl_toutSup,
      Sl_xferAck => opb_bus_Sl_xferAck,
      OPB_MRequest => open,
      OPB_ABus => opb_bus_OPB_ABus,
      OPB_BE => opb_bus_OPB_BE,
      OPB_beXfer => open,
      OPB_beAck => open,
      OPB_busLock => open,
      OPB_rdDBus => open,
      OPB_wrDBus => open,
      OPB_DBus => opb_bus_OPB_DBus,
      OPB_errAck => opb_bus_OPB_errAck,
      OPB_dwAck => open,
      OPB_dwXfer => open,
      OPB_fwAck => open,
      OPB_fwXfer => open,
      OPB_hwAck => open,
      OPB_hwXfer => open,
      OPB_MGrant => opb_bus_OPB_MGrant,
      OPB_pendReq => open,
      OPB_retry => opb_bus_OPB_retry,
      OPB_RNW => opb_bus_OPB_RNW,
      OPB_select => opb_bus_OPB_select,
      OPB_seqAddr => opb_bus_OPB_seqAddr,
      OPB_timeout => opb_bus_OPB_timeout,
      OPB_toutSup => open,
      OPB_xferAck => opb_bus_OPB_xferAck
    );

  gpio_switch0 : gpio_switch0_wrapper
    port map (
      OPB_Clk => clk_27mhz,
      OPB_Rst => opb_bus_OPB_Rst,
      OPB_ABus => opb_bus_OPB_ABus,
      OPB_BE => opb_bus_OPB_BE,
      OPB_DBus => opb_bus_OPB_DBus,
      OPB_RNW => opb_bus_OPB_RNW,
      OPB_select => opb_bus_OPB_select,
      OPB_seqAddr => opb_bus_OPB_seqAddr,
      GPIO_DBus => opb_bus_Sl_DBus(64 to 95),
      GPIO_errAck => opb_bus_Sl_errAck(2),
      GPIO_retry => opb_bus_Sl_retry(2),
      GPIO_toutSup => opb_bus_Sl_toutSup(2),
      GPIO_xferAck => opb_bus_Sl_xferAck(2),
      GPIO_IO_I => USER_INPUT0_P_I(0 to 0),
      GPIO_IO_O => USER_INPUT0_P_O(0 to 0),
      GPIO_IO_T => USER_INPUT0_P_T(0 to 0)
    );

  gpio_led0 : gpio_led0_wrapper
    port map (
      OPB_Clk => clk_27mhz,
      OPB_Rst => opb_bus_OPB_Rst,
      OPB_ABus => opb_bus_OPB_ABus,
      OPB_BE => opb_bus_OPB_BE,
      OPB_DBus => opb_bus_OPB_DBus,
      OPB_RNW => opb_bus_OPB_RNW,
      OPB_select => opb_bus_OPB_select,
      OPB_seqAddr => opb_bus_OPB_seqAddr,
      GPIO_DBus => opb_bus_Sl_DBus(96 to 127),
      GPIO_errAck => opb_bus_Sl_errAck(3),
      GPIO_retry => opb_bus_Sl_retry(3),
      GPIO_toutSup => opb_bus_Sl_toutSup(3),
      GPIO_xferAck => opb_bus_Sl_xferAck(3),
      GPIO_IO_I => USER_LED0_N_I(0 to 0),
      GPIO_IO_O => USER_LED0_N_O(0 to 0),
      GPIO_IO_T => USER_LED0_N_T(0 to 0)
    );

  ibuf_0 : IBUF
    port map (
      I => RS232_RX_DATA_P,
      O => RS232_RX_DATA_P_IBUF
    );

  obuf_1 : OBUF
    port map (
      I => RS232_TX_DATA_P_OBUF,
      O => RS232_TX_DATA_P
    );

  iobuf_2 : IOBUF
    port map (
      I => USER_INPUT0_P_O(0),
      IO => USER_INPUT0_P(0),
      O => USER_INPUT0_P_I(0),
      T => USER_INPUT0_P_T(0)
    );

  iobuf_3 : IOBUF
    port map (
      I => USER_LED0_N_O(0),
      IO => USER_LED0_N(0),
      O => USER_LED0_N_I(0),
      T => USER_LED0_N_T(0)
    );

  bufgp_4 : BUFGP
    port map (
      I => MASTER_CLOCK_P,
      O => clk_27mhz
    );

  ibuf_5 : IBUF
    port map (
      I => EXTEND_DCM_RESET_P,
      O => fpga_reset
    );

  ibuf_6 : IBUF
    port map (
      I => USER_INPUT1_P,
      O => switch1_led1
    );

  obuf_7 : OBUF
    port map (
      I => switch1_led1,
      O => USER_LED1_N
    );

end architecture STRUCTURE;
